==> solarus-0.9.0-src.tar.gz: solarus-0.9.0/include/entities/TimeScrollingTilePattern.h <==
/*
 * Copyright (C) 2009-2011 Christopho, Solarus - http://www.solarus-engine.org
 * 
 * Solarus is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Solarus is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program. If not, see <http://www.gnu.org/licenses/>.
 */
#ifndef SOLARUS_TIME_SCROLLING_TILE_PATTERN_H
#define SOLARUS_TIME_SCROLLING_TILE_PATTERN_H

#include "Common.h"
#include "entities/SimpleTilePattern.h"

/**
 * @brief Tile pattern with a scrolling effect.
 *
 * The pattern scrolls on itself with time,
 * giving the illusion of a movement.
 */
class TimeScrollingTilePattern: public SimpleTilePattern {

  private:

    static int shift;                   /**< number of pixels to shift, increased with the time */
    static uint32_t next_shift_date;    /**< when the shift variable is incremented */

  public:

    TimeScrollingTilePattern(Obstacle obstacle, int x, int y, int width, int height);
    ~TimeScrollingTilePattern();

    static void update();
    void display(Surface* destination, const Rectangle& dst_position,
            Tileset& tileset, const Rectangle& viewport);

    virtual bool is_animated();
};

#endif

==> solarus-1.1.1-src.tar.gz: solarus-1.1.1/include/entities/TimeScrollingTilePattern.h <==
/*
 * Copyright (C) 2006-2013 Christopho, Solarus - http://www.solarus-games.org
 * 
 * Solarus is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Solarus is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program. If not, see <http://www.gnu.org/licenses/>.
 */
#ifndef SOLARUS_TIME_SCROLLING_TILE_PATTERN_H
#define SOLARUS_TIME_SCROLLING_TILE_PATTERN_H

#include "Common.h"
#include "entities/SimpleTilePattern.h"

/**
 * \brief Tile pattern with a scrolling effect.
 *
 * The pattern scrolls on itself with time,
 * giving the illusion of a movement.
 */
class TimeScrollingTilePattern: public SimpleTilePattern {

  private:

    static int shift;                   /**< number of pixels to shift, increased with the time */
    static uint32_t next_shift_date;    /**< when the shift variable is incremented */

  public:

    TimeScrollingTilePattern(Ground ground, int x, int y, int width, int height);
    ~TimeScrollingTilePattern();

    static void update();
    void draw(Surface& dst_surface, const Rectangle& dst_position,
            Tileset& tileset, const Rectangle& viewport);

    virtual bool is_animated();
};

#endif
